// Part of BNC, a utility for retrieving decoding and
// converting GNSS data streams from NTRIP broadcasters.
//
// Copyright (C) 2007
// German Federal Agency for Cartography and Geodesy (BKG)
// http://www.bkg.bund.de
// Czech Technical University Prague, Department of Geodesy
// http://www.fsv.cvut.cz
//
// Email: euref-ip@bkg.bund.de
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation, version 2.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

/* -------------------------------------------------------------------------
 * BKG NTRIP Client
 * -------------------------------------------------------------------------
 *
 * Class:      t_pppWidgets
 *
 * Purpose:    This class stores widgets for PPP options
 *
 * Author:     L. Mervart
 *
 * Created:    29-Jul-2014
 *
 * Changes:    
 *
 * -----------------------------------------------------------------------*/

#include <iostream>

#include "PPP/pppwidgets.h"
#include "qtfilechooser.h"
#include "bncsettings.h"

using namespace std;

// Constructor
////////////////////////////////////////////////////////////////////////////
t_pppWidgets::t_pppWidgets() {
  _dataSource   = new QComboBox();     _dataSource  -> setObjectName("PPP/dataSource");
  _rinexObs     = new qtFileChooser(); _rinexObs    -> setObjectName("PPP/rinexObs");
  _rinexNav     = new qtFileChooser(); _rinexNav    -> setObjectName("PPP/rinexNav");
  _corrHostPort = new QLineEdit();     _corrHostPort-> setObjectName("PPP/corrHostPort"); 
  _corrFile     = new qtFileChooser(); _corrFile    -> setObjectName("PPP/corrFile"); 
  _crdFile      = new qtFileChooser(); _crdFile     -> setObjectName("PPP/crdFile");
  _antexFile    = new qtFileChooser(); _antexFile   -> setObjectName("PPP/antexFile");
  _logFile      = new QLineEdit();     _logFile     -> setObjectName("PPP/logFile");
  _nmeaFile     = new QLineEdit();     _nmeaFile    -> setObjectName("PPP/nmeaFile");
  _nmeaPort     = new QLineEdit();     _nmeaPort    -> setObjectName("PPP/nmeaPort");
  _staTable     = new QTableWidget();  _staTable    -> setObjectName("PPP/staTable");
  _lcGPS        = new QComboBox();     _lcGPS       -> setObjectName("PPP/lcGPS");
  _lcGLONASS    = new QComboBox();     _lcGLONASS   -> setObjectName("PPP/lcGLONASS");
  _lcGalileo    = new QComboBox();     _lcGalileo   -> setObjectName("PPP/lcGalileo");
  _sigmaC1      = new QLineEdit();     _sigmaC1     -> setObjectName("PPP/sigmaC1");
  _sigmaL1      = new QLineEdit();     _sigmaL1     -> setObjectName("PPP/sigmaL1");
  _corrWaitTime = new QSpinBox();      _corrWaitTime-> setObjectName("PPP/corrWaitTime");
}

// 
////////////////////////////////////////////////////////////////////////////
void t_pppWidgets::saveOptions() {

  bncSettings settings;

  settings.setValue(_dataSource  ->objectName(), _dataSource  ->currentText());
  settings.setValue(_rinexObs    ->objectName(), _rinexObs    ->fileName());
  settings.setValue(_rinexNav    ->objectName(), _rinexNav    ->fileName());
  settings.setValue(_corrHostPort->objectName(), _corrHostPort->text());
  settings.setValue(_corrFile    ->objectName(), _corrFile    ->fileName());
  settings.setValue(_crdFile     ->objectName(), _crdFile     ->fileName());
  settings.setValue(_antexFile   ->objectName(), _antexFile   ->fileName());
  settings.setValue(_logFile     ->objectName(), _logFile     ->text());
  settings.setValue(_nmeaFile    ->objectName(), _nmeaFile    ->text());
  settings.setValue(_nmeaPort    ->objectName(), _nmeaPort    ->text());
  settings.setValue(_lcGPS       ->objectName(), _lcGPS       ->currentText());
  settings.setValue(_lcGLONASS   ->objectName(), _lcGLONASS   ->currentText());
  settings.setValue(_lcGalileo   ->objectName(), _lcGalileo   ->currentText());
  settings.setValue(_sigmaC1     ->objectName(), _sigmaC1     ->text());
  settings.setValue(_sigmaL1     ->objectName(), _sigmaL1     ->text());
  settings.setValue(_corrWaitTime->objectName(), _corrWaitTime->value());

}
